@@ -46,11 +46,12 @@ using namespace eckit;
 
 
 namespace fdb5 {
+
 void LocalFDB::archive(const Key& key, const void* data, size_t length) {
 
     if (!archiver_) {
         LOG_DEBUG_LIB(LibFdb5) << *this << ": Constructing new archiver" << std::endl;
-        archiver_.reset(new Archiver(config_));
+        archiver_.reset(new Archiver(config_, callback_));
     }
 
     archiver_->archive(key, data, length);
