@@ -59,18 +59,18 @@ public: // methods
 
     MoveIterator move(const FDBToolRequest& request, const eckit::URI& dest) override;
 
+    AxesIterator axes(const FDBToolRequest& request, int axes) override;
+
     void flush() override;
 
-protected: // methods
-
-    template <typename VisitorType, typename ... Ts>
-    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts ... args);
-
 private: // methods
 
     void print(std::ostream& s) const override;
 
-protected: // members
+    template <typename VisitorType, typename ... Ts>
+    APIIterator<typename VisitorType::ValueType> queryInternal(const FDBToolRequest& request, Ts ... args);
+
+private: // members
 
     std::string home_;
 
