@@ -54,7 +54,7 @@ public: // methods
 
     Key combinedKey() const;
 
-    void print(std::ostream& out, bool withLocation=false, bool withLength=false) const;
+    void print(std::ostream& out, bool withLocation=false, bool withLength=false, bool withTimestamp=false, const char* sep = " ") const;
     void json(eckit::JSON& json) const;
 
 private: // methods
@@ -102,6 +102,13 @@ public:
     ListIterator(ListIterator&& iter) :
         APIIterator<ListElement>(std::move(iter)), seenKeys_(std::move(iter.seenKeys_)), deduplicate_(iter.deduplicate_) {}
 
+    ListIterator& operator=(ListIterator&& iter) {
+        seenKeys_ = std::move(iter.seenKeys_);
+        deduplicate_ = iter.deduplicate_;
+        APIIterator<ListElement>::operator=(std::move(iter));
+        return *this;
+    }
+
     bool next(ListElement& elem) {
         ListElement tmp;
         while (APIIterator<ListElement>::next(tmp)) {
