@@ -19,9 +19,8 @@
 #ifndef fdb5_api_local_ListVisitor_H
 #define fdb5_api_local_ListVisitor_H
 
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/database/Index.h"
-#include "fdb5/database/InspectionKey.h"
 #include "fdb5/api/local/QueryVisitor.h"
 #include "fdb5/api/helpers/ListIterator.h"
 
@@ -40,16 +39,14 @@ public:
 
     /// Make a note of the current database. Subtract its key from the current
     /// request so we can test request is used in its entirety
-//    bool visitDatabase(const Catalogue& catalogue, const Store& store) override {
-    bool visitDatabase(const Catalogue& catalogue) override {
+    bool visitDatabase(const Catalogue& catalogue, const Store& store) override {
 
         // If the DB is locked for listing, then it "doesn't exist"
         if (!catalogue.enabled(ControlIdentifier::List)) {
             return false;
         }
 
-//        bool ret = QueryVisitor::visitDatabase(catalogue, store);
-        bool ret = QueryVisitor::visitDatabase(catalogue);
+        bool ret = QueryVisitor::visitDatabase(catalogue, store);
         ASSERT(catalogue.key().partialMatch(request_));
 
         // Subselect the parts of the request
@@ -82,12 +79,12 @@ public:
     }
 
     /// Test if entry matches the current request. If so, add to the output queue.
-    void visitDatum(const Field& field, const InspectionKey& datumKey) override {
+    void visitDatum(const Field& field, const Key& key) override {
         ASSERT(currentCatalogue_);
         ASSERT(currentIndex_);
 
-        if (datumKey.match(datumRequest_)) {
-            queue_.emplace(ListElement({currentCatalogue_->key(), currentIndex_->key(), datumKey.canonical()}, field.stableLocation(), field.timestamp()));
+        if (key.match(datumRequest_)) {
+            queue_.emplace(ListElement({currentCatalogue_->key(), currentIndex_->key(), key}, field.stableLocation(), field.timestamp()));
         }
     }
 
