@@ -42,10 +42,9 @@ public: // methods
     bool visitIndexes() override { return false; }
     bool visitEntries() override { return false; }
 
-//    bool visitDatabase(const Catalogue& catalogue, const Store& store) override;
-    bool visitDatabase(const Catalogue& catalogue) override;
+    bool visitDatabase(const Catalogue& catalogue, const Store& store) override;
     bool visitIndex(const Index&) override { NOTIMP; }
-    void visitDatum(const Field&, const InspectionKey&) override { NOTIMP; }
+    void visitDatum(const Field&, const Key&) override { NOTIMP; }
     void visitDatum(const Field& field, const std::string& keyFingerprint) override { NOTIMP; }
 
 private: // members
