@@ -30,11 +30,11 @@ class ArchiveVisitor : public BaseArchiveVisitor {
 
 public: // methods
 
-    ArchiveVisitor(Archiver &owner, const Key &dataKey, const void *data, size_t size);
+    ArchiveVisitor(Archiver &owner, const Key &field, const void *data, size_t size, const ArchiveCallback& callback = CALLBACK_NOOP);
 
 protected: // methods
 
-    virtual bool selectDatum(const InspectionKey &key, const Key &full) override;
+    virtual bool selectDatum(const Key &key, const Key &full) override;
 
     virtual void print( std::ostream &out ) const override;
 
@@ -42,6 +42,9 @@ private: // members
 
     const void *data_;
     size_t size_;
+
+    const ArchiveCallback& callback_;
+
 };
 
 //----------------------------------------------------------------------------------------------------------------------
