@@ -24,9 +24,10 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 
-Archiver::Archiver(const Config& dbConfig) :
+Archiver::Archiver(const Config& dbConfig, const ArchiveCallback& callback) :
     dbConfig_(dbConfig),
-    current_(nullptr) {
+    current_(nullptr),
+    callback_(callback) {
 }
 
 Archiver::~Archiver() {
@@ -37,7 +38,7 @@ Archiver::~Archiver() {
 }
 
 void Archiver::archive(const Key &key, const void* data, size_t len) {
-    ArchiveVisitor visitor(*this, key, data, len);
+    ArchiveVisitor visitor(*this, key, data, len, callback_);
     archive(key, visitor);
 }
 
