@@ -18,6 +18,7 @@
 
 #include "fdb5/config/Config.h"
 #include "fdb5/database/Field.h"
+#include "fdb5/database/DatabaseNotFoundException.h"
 
 namespace fdb5 {
 
@@ -25,7 +26,7 @@ class Catalogue;
 class Store;
 class FDBToolRequest;
 class Index;
-class InspectionKey;
+class Key;
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -40,27 +41,24 @@ public:  // methods
     virtual bool visitIndexes() { return true; }
     virtual bool visitEntries() { return true; }
 
-//    virtual bool visitDatabase(const Catalogue& catalogue, const Store& store);    // return true if Catalogue should be explored
-    virtual bool visitDatabase(const Catalogue& catalogue);    // return true if Catalogue should be explored
+    virtual bool visitDatabase(const Catalogue& catalogue, const Store& store);    // return true if Catalogue should be explored
     virtual bool visitIndex(const Index& index); // return true if index should be explored
     virtual void catalogueComplete(const Catalogue& catalogue);
     virtual void visitDatum(const Field& field, const std::string& keyFingerprint);
 
+    virtual void onDatabaseNotFound(const fdb5::DatabaseNotFoundException& e) {}
+
     time_t indexTimestamp() const;
 
-protected:
-
-    Store& store();
-
 private: // methods
 
-    virtual void visitDatum(const Field& field, const InspectionKey& key) = 0;
+    virtual void visitDatum(const Field& field, const Key& key) = 0;
 
 protected:  // members
 
     // n.b. non-owning
     const Catalogue* currentCatalogue_;
-    std::unique_ptr<Store> currentStore_;
+    const Store* currentStore_;
     const Index* currentIndex_;
 };
 
