@@ -48,13 +48,13 @@ bool InspectIterator::next(ListElement& elem) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-static void purgeCatalogue(Key& key, CatalogueReader*& db) {
-    Log::debug() << "Purging DB with key " << key << std::endl;
+static void purgeDB(Key& key, DB*& db) {
+    LOG_DEBUG_LIB(LibFdb5) << "Purging DB with key " << key << std::endl;
     delete db;
 }
 
 Inspector::Inspector(const Config& dbConfig) :
-    databases_(Resource<size_t>("fdbMaxOpenDatabases", 16), &purgeCatalogue),
+    databases_(Resource<size_t>("fdbMaxOpenDatabases", 16), &purgeDB),
     dbConfig_(dbConfig) {}
 
 Inspector::~Inspector() {
@@ -67,7 +67,7 @@ ListIterator Inspector::inspect(const metkit::mars::MarsRequest& request,
     InspectIterator* iterator = new InspectIterator();
     MultiRetrieveVisitor visitor(notifyee, *iterator, databases_, dbConfig_);
 
-    Log::debug<LibFdb5>() << "Using schema: " << schema << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Using schema: " << schema << std::endl;
 
     schema.expand(request, visitor);
 
