@@ -38,7 +38,7 @@ public: // methods
     bool visitEntries() override { return false; }
 
     bool visitIndex(const Index&) override { NOTIMP; }
-    void visitDatum(const Field&, const InspectionKey&) override { NOTIMP; }
+    void visitDatum(const Field&, const Key&) override { NOTIMP; }
     void visitDatum(const Field& /*field*/, const std::string& /*keyFingerprint*/) override { NOTIMP; }
 
 protected: // members
