@@ -15,7 +15,7 @@
 #include "eckit/config/Resource.h"
 
 #include "fdb5/LibFdb5.h"
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/database/Key.h"
 #include "fdb5/io/HandleGatherer.h"
 #include "fdb5/types/Type.h"
@@ -29,8 +29,9 @@ namespace fdb5 {
 
 MultiRetrieveVisitor::MultiRetrieveVisitor(const Notifier& wind,
                                            InspectIterator& iterator,
-                                           eckit::CacheLRU<Key,CatalogueReader*>& databases,
+                                           eckit::CacheLRU<Key,DB*>& databases,
                                            const Config& config) :
+    db_(nullptr),
     wind_(wind),
     databases_(databases),
     iterator_(iterator),
@@ -44,12 +45,12 @@ MultiRetrieveVisitor::~MultiRetrieveVisitor() {
 
 bool MultiRetrieveVisitor::selectDatabase(const Key& key, const Key&) {
 
-	eckit::Log::debug<LibFdb5>() << "FDB5 selectDatabase " << key  << std::endl;
+	LOG_DEBUG_LIB(LibFdb5) << "FDB5 selectDatabase " << key  << std::endl;
 
     /* is it the current DB ? */
 
-    if(catalogue_) {
-        if(key == catalogue_->key()) {
+    if(db_) {
+        if(key == db_->key()) {
             eckit::Log::info() << "This is the current db" << std::endl;
             return true;
         }
@@ -58,47 +59,48 @@ bool MultiRetrieveVisitor::selectDatabase(const Key& key, const Key&) {
     /* is the DB already open ? */
 
     if(databases_.exists(key)) {
-        eckit::Log::debug<LibFdb5>() << "FDB5 Reusing database " << key << std::endl;
-        catalogue_ = databases_.access(key);
+        LOG_DEBUG_LIB(LibFdb5) << "FDB5 Reusing database " << key << std::endl;
+        db_ = databases_.access(key);
         return true;
     }
 
     /* DB not yet open */
 
-    std::unique_ptr<CatalogueReader> newCatalogue = CatalogueReaderFactory::instance().build(key, config_);
+    //std::unique_ptr<DB> newDB( DBFactory::buildReader(key, config_) );
+    std::unique_ptr<DB> newDB = DB::buildReader(key, config_);
 
     // If this database is locked for retrieval then it "does not exist"
-    if (!newCatalogue->enabled(ControlIdentifier::Retrieve)) {
+    if (!newDB->enabled(ControlIdentifier::Retrieve)) {
         std::ostringstream ss;
-        ss << "Catalogue " << *newCatalogue << " is LOCKED for retrieval";
+        ss << "Database " << *newDB << " is LOCKED for retrieval";
         eckit::Log::warning() << ss.str() << std::endl;
         return false;
     }
 
-    eckit::Log::debug<LibFdb5>() << "selectDatabase opening database " << key << " (type=" << newCatalogue->type() << ")" << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "selectDatabase opening database " << key << " (type=" << newDB->dbType() << ")" << std::endl;
 
-    if (!newCatalogue->open()) {
-        eckit::Log::debug() << "Database does not exist " << key << std::endl;
+    if (!newDB->open()) {
+        LOG_DEBUG_LIB(LibFdb5) << "Database does not exist " << key << std::endl;
         return false;
     } else {
-        catalogue_ = newCatalogue.release();
-        databases_.insert(key, catalogue_);
+        db_ = newDB.release();
+        databases_.insert(key, db_);
         return true;
     }
 }
 
 bool MultiRetrieveVisitor::selectIndex(const Key& key, const Key&) {
-    ASSERT(catalogue_);
-    eckit::Log::debug() << "selectIndex " << key << std::endl;
-    return catalogue_->selectIndex(key);
+    ASSERT(db_);
+    LOG_DEBUG_LIB(LibFdb5) << "selectIndex " << key << std::endl;
+    return db_->selectIndex(key);
 }
 
-bool MultiRetrieveVisitor::selectDatum(const InspectionKey& key, const Key& full) {
-    ASSERT(catalogue_);
-    eckit::Log::debug() << "selectDatum " << key << ", " << full << std::endl;
+bool MultiRetrieveVisitor::selectDatum(const Key& key, const Key& full) {
+    ASSERT(db_);
+    LOG_DEBUG_LIB(LibFdb5) << "selectDatum " << key << ", " << full << std::endl;
 
     Field field;
-    if (catalogue_->retrieve(key, field)) {
+    if (db_->inspect(key, field)) {
 
         Key simplifiedKey;
         for (auto k = key.begin(); k != key.end(); k++) {
@@ -106,7 +108,7 @@ bool MultiRetrieveVisitor::selectDatum(const InspectionKey& key, const Key& full
                 simplifiedKey.set(k->first, k->second);
         }
 
-        iterator_.emplace(ListElement({catalogue_->key(), catalogue_->indexKey(), simplifiedKey}, field.stableLocation(), field.timestamp()));
+        iterator_.emplace(ListElement({db_->key(), db_->indexKey(), simplifiedKey}, field.stableLocation(), field.timestamp()));
         return true;
     }
 
@@ -118,12 +120,12 @@ void MultiRetrieveVisitor::values(const metkit::mars::MarsRequest &request,
                              const TypesRegistry &registry,
                              eckit::StringList &values) {
     eckit::StringList list;
-    registry.lookupType(keyword).getValues(request, keyword, list, wind_, catalogue_);
+    registry.lookupType(keyword).getValues(request, keyword, list, wind_, db_);
 
     eckit::StringSet filter;
     bool toFilter = false;
-    if (catalogue_) {
-        toFilter = catalogue_->axis(keyword, filter);
+    if (db_) {
+        toFilter = db_->axis(keyword, filter);
     }
 
     for(auto l: list) {
@@ -139,8 +141,8 @@ void MultiRetrieveVisitor::print( std::ostream &out ) const {
 }
 
 const Schema& MultiRetrieveVisitor::databaseSchema() const {
-    ASSERT(catalogue_);
-    return catalogue_->schema();
+    ASSERT(db_);
+    return db_->schema();
 }
 
 //----------------------------------------------------------------------------------------------------------------------
