@@ -57,6 +57,13 @@ public:
     virtual void remove(const Key& key) const { NOTIMP; }
 
     virtual eckit::URI uri() const = 0;
+    virtual bool uriBelongs(const eckit::URI&) const = 0;
+    virtual bool uriExists(const eckit::URI& uri) const = 0;
+    virtual std::vector<eckit::URI> collocatedDataURIs() const = 0;
+    virtual std::set<eckit::URI> asCollocatedDataURIs(const std::vector<eckit::URI>&) const = 0;
+
+    virtual std::vector<eckit::URI> getAuxiliaryURIs(const eckit::URI&) const { NOTIMP; }
+    virtual bool auxiliaryURIExists(const eckit::URI&) const { NOTIMP; }
 
 protected: // members
     const Schema& schema_;  //<< schema is owned by catalogue which always outlives the store
@@ -72,13 +79,11 @@ public:
     StoreBuilderBase(const std::string&);
     virtual ~StoreBuilderBase();
     virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) = 0;
-    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) = 0;
 };
 
 template <class T>
 class StoreBuilder : public StoreBuilderBase {
     virtual std::unique_ptr<Store> make(const Schema& schema, const Key& key, const Config& config) override { return std::unique_ptr<T>(new T(schema, key, config)); }
-    virtual std::unique_ptr<Store> make(const Schema& schema, const eckit::URI& uri, const Config& config) override { return std::unique_ptr<T>(new T(schema, uri, config)); }
 
 public:
     StoreBuilder(const std::string& name) : StoreBuilderBase(name) {}
@@ -101,12 +106,6 @@ public:
     /// @returns         store built by specified builder
     std::unique_ptr<Store> build(const Schema& schema, const Key& key, const Config& config);
 
-    /// @param schema    the schema read by the catalog
-    /// @param uri       search uri
-    /// @param config    the fdb config
-    /// @returns         store built by specified builder
-    std::unique_ptr<Store> build(const Schema& schema, const eckit::URI& uri, const Config& config);
-
 private:
     StoreFactory();
 
