@@ -35,8 +35,8 @@ RadosFieldLocation::RadosFieldLocation(const eckit::URI &uri, eckit::Offset offs
 RadosFieldLocation::RadosFieldLocation(const RadosFieldLocation& rhs) :
     FieldLocation(rhs.uri_) {}
 
-// RadosFieldLocation::RadosFieldLocation(const FileStore &store, const FieldRef &ref) :
-//     FieldLocation(store.get(ref.pathId()), ref.offset(), ref.length()) {}
+RadosFieldLocation::RadosFieldLocation(const FileStore &store, const FieldRef &ref) :
+    FieldLocation(store.get(ref.pathId()), ref.offset(), ref.length()) {}
 
 RadosFieldLocation::RadosFieldLocation(eckit::Stream& s) :
     FieldLocation(s) {}
