@@ -52,7 +52,7 @@ public:
     DbPathNamer(const std::string& keyregex, const std::string& format) :
         format_(format){
         crack(keyregex);
-        eckit::Log::debug<LibFdb5>() << "Building " << *this << std::endl;
+        LOG_DEBUG_LIB(LibFdb5) << "Building " << *this << std::endl;
     }
 
     /// Full match of the incomming key with the key regex
@@ -236,7 +236,7 @@ static const DbPathNamerTable& readDbNamers(const Config& config) {
 
     if(filename.exists()) {
 
-        eckit::Log::debug<LibFdb5>() << "Loading FDB DBPathNames from " << fdbDbNamesFile << std::endl;
+        LOG_DEBUG_LIB(LibFdb5) << "Loading FDB DBPathNames from " << fdbDbNamesFile << std::endl;
 
         std::ifstream in(filename.localPath());
 
@@ -299,7 +299,7 @@ static std::vector<Root> readRoots(const eckit::PathName& fdbRootsFile) {
 
     std::ifstream in(fdbRootsFile.localPath());
 
-    eckit::Log::debug<LibFdb5>() << "Loading FDB roots from " << fdbRootsFile << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Loading FDB roots from " << fdbRootsFile << std::endl;
 
     if (!in) {
         eckit::Log::error() << fdbRootsFile << eckit::Log::syserr << std::endl;
@@ -417,7 +417,7 @@ static FileSpaceTable parseFileSpacesFile(const eckit::PathName& fdbHome) {
     eckit::PathName fdbSpacesFile = eckit::Resource<eckit::PathName>("fdbSpacesFile;$FDB_SPACES_FILE", fdbHome / "etc/fdb/spaces");
     std::ifstream in(fdbSpacesFile.localPath());
 
-    eckit::Log::debug<LibFdb5>() << "Loading FDB file spaces from " << fdbSpacesFile << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Loading FDB file spaces from " << fdbSpacesFile << std::endl;
 
     if (!in) {
         throw eckit::ReadError(fdbSpacesFile, Here());
@@ -570,24 +570,24 @@ std::string RootManager::dbPathName(const Key& key)
     for (DbPathNamerTable::const_iterator i = dbPathNamers_.begin(); i != dbPathNamers_.end() ; ++i) {
         if(i->match(key)) {
             dbpath = i->name(key);
-            eckit::Log::debug<LibFdb5>() << "DbName is " << dbpath << " for key " << key <<  std::endl;
+            LOG_DEBUG_LIB(LibFdb5) << "DbName is " << dbpath << " for key " << key <<  std::endl;
             return dbpath;
         }
     }
 
     // default naming convention for DB's
     dbpath = key.valuesToString();
-    eckit::Log::debug<LibFdb5>() << "Using default naming convention for key " << key << " -> " << dbpath <<  std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Using default naming convention for key " << key << " -> " << dbpath <<  std::endl;
     return dbpath;
 }
 
-std::vector<std::string> RootManager::possibleDbPathNames(const InspectionKey& key, const char* missing)
+std::vector<std::string> RootManager::possibleDbPathNames(const Key& key, const char* missing)
 {
     std::vector<std::string> result;
     for (DbPathNamerTable::const_iterator i = dbPathNamers_.begin(); i != dbPathNamers_.end() ; ++i) {
         if(i->match(key, missing)) {
             std::string dbpath = i->namePartial(key, missing);
-            eckit::Log::debug<LibFdb5>() << "Matched " << *i << " with key " << key << " resulting in dbpath " << dbpath << std::endl;
+            LOG_DEBUG_LIB(LibFdb5) << "Matched " << *i << " with key " << key << " resulting in dbpath " << dbpath << std::endl;
             result.push_back(dbpath);
         }
     }
@@ -605,7 +605,7 @@ std::vector<std::string> RootManager::possibleDbPathNames(const InspectionKey& k
     }
     result.push_back(oss.str());
 
-    eckit::Log::debug<LibFdb5>() << "Using default naming convention for key " << key << " -> " << result.back() <<  std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Using default naming convention for key " << key << " -> " << result.back() <<  std::endl;
 
     return result;
 }
@@ -615,7 +615,7 @@ TocPath RootManager::directory(const Key& key) {
 
     PathName dbpath = dbPathName(key);
 
-    eckit::Log::debug<LibFdb5>() << "Choosing directory for key " << key << " dbpath " << dbpath << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Choosing directory for key " << key << " dbpath " << dbpath << std::endl;
 
     // override root location for testing purposes only
 
@@ -631,9 +631,9 @@ TocPath RootManager::directory(const Key& key) {
 
     for (FileSpaceTable::const_iterator i = spacesTable_.begin(); i != spacesTable_.end() ; ++i) {
         if(i->match(keystr)) {
-            TocPath db = i->filesystem(key, dbpath);
-            eckit::Log::debug<LibFdb5>() << "Database directory " << db.directory_ << std::endl;
-            return db;
+            TocPath root = i->filesystem(key, dbpath);
+            LOG_DEBUG_LIB(LibFdb5) << "Directory root " << root.directory_ << " dbpath " << dbpath <<  std::endl;
+            return TocPath{root.directory_ / dbpath, root.controlIdentifiers_};
         }
     }
 
@@ -657,7 +657,7 @@ std::vector<PathName> RootManager::allRoots(const Key& key)
     return std::vector<eckit::PathName>(roots.begin(), roots.end());
 }
 
-std::vector<PathName> RootManager::visitableRoots(const std::set<InspectionKey>& keys) {
+std::vector<PathName> RootManager::visitableRoots(const std::set<Key>& keys) {
 
     eckit::StringSet roots;
 
@@ -665,38 +665,38 @@ std::vector<PathName> RootManager::visitableRoots(const std::set<InspectionKey>&
     std::transform(keys.begin(), keys.end(), std::back_inserter(keystrings),
                    [](const Key& k) { return k.valuesToString(); });
 
-    Log::debug<LibFdb5>() << "RootManager::visitableRoots() trying to match keys " << keystrings << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "RootManager::visitableRoots() trying to match keys " << keystrings << std::endl;
 
     for (const auto& space : spacesTable_) {
 
         bool matched = false;
         for (const std::string& k : keystrings) {
             if (space.match(k) || k.empty()) {
-                Log::debug<LibFdb5>() << "MATCH space " << space << std::endl;
+                LOG_DEBUG_LIB(LibFdb5) << "MATCH space " << space << std::endl;
                 space.enabled(ControlIdentifier::List,roots);
                 matched = true;
                 break;
             }
         }
 
-        if (!matched) Log::debug<LibFdb5>() << "FAIL to match space " << space << std::endl;
+        if (!matched) LOG_DEBUG_LIB(LibFdb5) << "FAIL to match space " << space << std::endl;
     }
 
-    Log::debug<LibFdb5>() << "Visitable Roots " << roots << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Visitable Roots " << roots << std::endl;
 
     return std::vector<eckit::PathName>(roots.begin(), roots.end());
 }
 
 
-std::vector<eckit::PathName> RootManager::visitableRoots(const InspectionKey& key) {
-    return visitableRoots(std::set<InspectionKey>{ key });
+std::vector<eckit::PathName> RootManager::visitableRoots(const Key& key) {
+    return visitableRoots(std::set<Key>{ key });
 }
 
 std::vector<eckit::PathName> RootManager::visitableRoots(const metkit::mars::MarsRequest& request) {
 
 //    Key key;
 //    config_.schema().expandFirstLevel(request, key);
-    std::set<InspectionKey> keys;
+    std::set<Key> keys;
     config_.schema().matchFirstLevel(request, keys, "");
     return visitableRoots(keys);
 }
@@ -715,7 +715,7 @@ std::vector<eckit::PathName> RootManager::canArchiveRoots(const Key& key) {
         }
     }
 
-    Log::debug<LibFdb5>() << "Roots supporting archival " << roots << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Roots supporting archival " << roots << std::endl;
 
     return std::vector<eckit::PathName>(roots.begin(), roots.end());
 }
@@ -733,7 +733,7 @@ std::vector<eckit::PathName> RootManager::canMoveToRoots(const Key& key) {
         }
     }
 
-    Log::debug<LibFdb5>() << "Roots supporting wiping " << roots << std::endl;
+    LOG_DEBUG_LIB(LibFdb5) << "Roots supporting wiping " << roots << std::endl;
 
     return std::vector<eckit::PathName>(roots.begin(), roots.end());
 }
