@@ -28,7 +28,7 @@ class TocCatalogueReader : public TocCatalogue, public CatalogueReader {
 
 public: // methods
 
-    TocCatalogueReader(const Key& dbKey, const fdb5::Config& config);
+    TocCatalogueReader(const Key& key, const fdb5::Config& config);
     TocCatalogueReader(const eckit::URI& uri, const fdb5::Config& config);
 
     ~TocCatalogueReader() override;
@@ -39,7 +39,7 @@ public: // methods
 private: // methods
 
     void loadIndexesAndRemap();
-    bool selectIndex(const Key &idxKey) override;
+    bool selectIndex(const Key &key) override;
     void deselectIndex() override;
 
     bool open() override;
@@ -49,7 +49,7 @@ private: // methods
     
     bool axis(const std::string &keyword, eckit::StringSet &s) const override;
 
-    bool retrieve(const InspectionKey& key, Field& field) const override;
+    bool retrieve(const Key& key, Field& field) const override;
 
     void print( std::ostream &out ) const override;
 
