@@ -25,7 +25,7 @@
 
 #include "fdb5/config/Config.h"
 #include "fdb5/database/DbStats.h"
-#include "fdb5/database/Catalogue.h"
+#include "fdb5/database/DB.h"
 #include "fdb5/toc/TocCommon.h"
 #include "fdb5/toc/TocRecord.h"
 #include "fdb5/toc/TocSerialisationVersion.h"
@@ -102,7 +102,7 @@ public: // typedefs
 
 public: // methods
 
-    //TocHandler( const Key &key, const Config& config);
+    TocHandler( const Key &key, const Config& config);
 
     TocHandler( const eckit::PathName &dir, const Config& config);
 
@@ -173,7 +173,6 @@ private: // methods
 protected: // members
 
     mutable Key parentKey_; // Contains the key of the first TOC explored in subtoc chain
-    const eckit::PathName schemaPath_;
 
     uid_t dbUID() const override;
 
