@@ -87,7 +87,7 @@ public: // methods
 private: // methods
 
     const IndexLocation& location() const override { return location_; }
-    const std::vector<eckit::URI> dataPaths() const override;
+    const std::vector<eckit::URI> dataURIs() const override;
 
     bool dirty() const override;
 
