@@ -35,8 +35,7 @@ public:
 
 private: // methods
 
-    // bool visitDatabase(const Catalogue& catalogue, const Store& store) override;
-    bool visitDatabase(const Catalogue& catalogue) override;
+    bool visitDatabase(const Catalogue& catalogue, const Store& store) override;
 
     void move();
 
