@@ -35,17 +35,80 @@ namespace fdb5 {
 //----------------------------------------------------------------------------------------------------------------------
 
 TocStore::TocStore(const Schema& schema, const Key& key, const Config& config) :
-    Store(schema), TocCommon(StoreRootManager(config).directory(key).directory_) {}
-
-TocStore::TocStore(const Schema& schema, const eckit::URI& uri, const Config& config) :
-    Store(schema), TocCommon(uri.path().dirName()) {}
+    Store(schema),
+    TocCommon(StoreRootManager(config).directory(key).directory_),
+    auxFileExtensions_{auxFileExtensions()} {}
 
 eckit::URI TocStore::uri() const {
+
     return URI("file", directory_);
+
+}
+
+bool TocStore::uriBelongs(const eckit::URI& uri) const {
+
+    // TODO: assert uri represents a (not necessarily existing) data file
+    return ((uri.scheme() == type()) && (uri.path().dirName().sameAs(directory_)));
+
+}
+
+bool TocStore::uriExists(const eckit::URI& uri) const {
+
+    ASSERT(uri.scheme() == type());
+    eckit::PathName p(uri.path());
+    // ensure provided URI is either DB URI or Store file URI
+    if (!p.sameAs(directory_)) {
+        ASSERT(p.dirName().sameAs(directory_));
+        ASSERT(p.extension() == ".data");
+    }
+
+    return p.exists();
+
+}
+
+bool TocStore::auxiliaryURIExists(const eckit::URI& uri) const  {
+    ASSERT(uri.scheme() == type());
+    eckit::PathName p(uri.path());
+    ASSERT(p.dirName().sameAs(directory_));
+    return p.exists();
+}
+
+std::vector<eckit::URI> TocStore::collocatedDataURIs() const {
+
+    std::vector<eckit::PathName> files;
+    std::vector<eckit::PathName> dirs;
+    (directory_).children(files, dirs);
+
+    std::vector<eckit::URI> res;
+    for (const auto& f : files) {
+        if (f.extension() == ".data") {
+            res.push_back(eckit::URI{type(), f});
+        }
+    }
+
+    return res;
+
+}
+
+std::set<eckit::URI> TocStore::asCollocatedDataURIs(const std::vector<eckit::URI>& uris) const {
+
+    std::set<eckit::URI> res;
+
+    for (auto& uri : uris) {
+
+        ASSERT(uri.path().extension() == ".data");
+        res.insert(uri);
+
+    }
+
+    return res;
+
 }
 
 bool TocStore::exists() const {
+
     return directory_.exists();
+
 }
 
 eckit::DataHandle* TocStore::retrieve(Field& field) const {
@@ -65,7 +128,7 @@ std::unique_ptr<FieldLocation> TocStore::archive(const Key &key, const void *dat
 
     ASSERT(len == length);
 
-    return std::unique_ptr<TocFieldLocation>(new TocFieldLocation(dataPath, position, length, Key()));
+    return std::unique_ptr<TocFieldLocation>(new TocFieldLocation(dataPath, position, length, Key(nullptr, true)));
 }
 
 void TocStore::flush() {
@@ -230,11 +293,36 @@ bool TocStore::canMoveTo(const Key& key, const Config& config, const eckit::URI&
 //     src.copyTo(dest);
 // }
 
+eckit::URI TocStore::getAuxiliaryURI(const eckit::URI& uri, const std::string& ext) const {
+    // Filebackend: ext is a suffix to append to the file name
+    ASSERT(uri.scheme() == type());
+    eckit::PathName path = uri.path() + "." + ext;
+    return eckit::URI(type(), path);
+}
+
+std::vector<eckit::URI> TocStore::getAuxiliaryURIs(const eckit::URI& uri) const {
+    ASSERT(uri.scheme() == type());
+    std::vector<eckit::URI> uris;
+    for (const auto& e : LibFdb5::instance().auxiliaryRegistry()) {
+        uris.push_back(getAuxiliaryURI(uri, e));
+    }
+    return uris;
+}
+
+std::set<std::string> TocStore::auxFileExtensions() const {
+    std::set<std::string> extensions;
+    for (const auto& e : LibFdb5::instance().auxiliaryRegistry()) {
+        extensions.insert("." + e);
+    }
+    return extensions;
+}
+
 void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& dest, eckit::Queue<MoveElement>& queue) const {
     eckit::PathName destPath = dest.path();
+
     for (const eckit::PathName& root: StoreRootManager(config).canMoveToRoots(key)) {
         if (root.sameAs(destPath)) {      
-            eckit::PathName src_db = directory_ / key.valuesToString();
+            eckit::PathName src_db = directory_;
             eckit::PathName dest_db = destPath / key.valuesToString();
 
             dest_db.mkdir();
@@ -244,9 +332,11 @@ void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& de
             while ((dp = ::readdir(dirp)) != NULL) {
                 if (strstr( dp->d_name, ".data")) {
                     eckit::PathName file(src_db / dp->d_name);
-                    struct stat fileStat;
-                    ::stat(file.asString().c_str(), &fileStat);
-                    files.emplace(fileStat.st_size, new FileCopy(src_db.path(), dest_db, dp->d_name));
+                    if ((file.extension() == ".data") || auxFileExtensions_.find(file.extension()) != auxFileExtensions_.end()) {
+                        struct stat fileStat;
+                        SYSCALL(::stat(file.asString().c_str(), &fileStat));
+                        files.emplace(fileStat.st_size, new FileCopy(src_db.path(), dest_db, dp->d_name));
+                    }
                 }
             }
             closedir(dirp);
@@ -260,7 +350,7 @@ void TocStore::moveTo(const Key& key, const Config& config, const eckit::URI& de
 
 void TocStore::remove(const Key& key) const {
 
-    eckit::PathName src_db = directory_ / key.valuesToString();
+    eckit::PathName src_db = directory_;
         
     DIR* dirp = ::opendir(src_db.asString().c_str());
     struct dirent* dp;
