@@ -18,46 +18,17 @@ namespace fdb5 {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-eckit::ClassSpec TypesRegistry::classSpec_ = { &eckit::Streamable::classSpec(), "TypesRegistry", };
-
-eckit::Reanimator<TypesRegistry> TypesRegistry::reanimator_;
-
 TypesRegistry::TypesRegistry():
     parent_(nullptr) {
 }
 
-TypesRegistry::TypesRegistry(eckit::Stream& s):
-    parent_(nullptr) {
-
-    size_t numTypes;
-    std::string name;
-    std::string type;
-
-    s >> numTypes;
-    for (size_t i=0; i<numTypes; i++) {
-        s >> name;
-        s >> type;
-        types_[name] = type;
-    }
-}
-
-void TypesRegistry::encode(eckit::Stream& s) const {
-
-    s << types_.size();
-    for (auto t: types_) {
-        s << t.first;
-        s << t.second;
-    }
-}
-
-
 TypesRegistry::~TypesRegistry() {
     for (TypeMap::iterator i = cache_.begin(); i != cache_.end(); ++i) {
         delete (*i).second;
     }
 }
 
-void TypesRegistry::updateParent(const TypesRegistry *parent) {
+void TypesRegistry::updateParent(std::shared_ptr<TypesRegistry> parent) {
     parent_ = parent;
 }
 
@@ -85,7 +56,7 @@ const Type &TypesRegistry::lookupType(const std::string &keyword) const {
         }
 
         // eckit::Log::info() << "Type of " << keyword << " is " << type << std::endl;
-        Type *newKH = TypesFactory::build(type, keyword);
+        Type* newKH = TypesFactory::build(type, keyword);
         cache_[keyword] = newKH;
         return *newKH;
     }
