@@ -24,9 +24,6 @@
 #include "eckit/runtime/Main.h"
 #include "eckit/types/Types.h"
 #include "eckit/utils/Translator.h"
-#include "eckit/serialisation/MemoryStream.h"
-#include "eckit/serialisation/FileStream.h"
-#include "eckit/io/AutoCloser.h"
 
 #include "metkit/mars/MarsRequest.h"
 #include "metkit/mars/MarsExpension.h"
@@ -55,6 +52,7 @@ struct FixtureService {
 
     metkit::mars::MarsRequest env;
     StringDict p;
+    fdb5::Config config;
 
 	std::vector<std::string> modelParams_;
 
@@ -98,7 +96,7 @@ struct FixtureService {
 						 << std::endl;
 					std::string data_str = data.str();
 
-                    fdb5::Key k(p);
+                    fdb5::Key k(p, config.schema().registry());
                     ArchiveVisitor visitor(fdb, k, static_cast<const void *>(data_str.c_str()), data_str.size());
                     fdb.archive(k, visitor);
 				}
@@ -315,6 +313,9 @@ CASE ( "test_fdb_service" ) {
             	while ((dp = ::readdir(dirp)) != nullptr) {
                 	EXPECT_NOT(strstr( dp->d_name, "toc."));
 				}
+
+				// consuming the rest of the queue
+				while (iter.next(el));
 			}
         }
 
@@ -499,6 +500,9 @@ CASE ( "test_fdb_service_subtoc" ) {
 					}
 				}
 				EXPECT(subtoc);
+
+				// consuming the rest of the queue
+				while (iter.next(el));
 			}
         }
 
@@ -551,42 +555,6 @@ CASE ( "test_fdb_service_subtoc" ) {
 	}
 }
 
-CASE( "schemaSerialisation" ) {
-
-	PathName filename    = PathName::unique("data");                                             
-	std::string filepath = filename.asString();
-
-	std::string original;
-	
-	{
-		eckit::FileStream sout(filepath.c_str(), "w");
-		auto c = eckit::closer(sout);
-
-		fdb5::Config config;
-		config = config.expandConfig();
-		
-		std::stringstream ss;
-		config.schema().dump(ss);
-		original = ss.str();
-
-		sout << config.schema();
-	}
-	{                                                                                           
-		eckit::FileStream sin(filepath.c_str(), "r");
-		auto c = eckit::closer(sin);
-
-		fdb5::Schema* clone = eckit::Reanimator<fdb5::Schema>::reanimate(sin);
-
-		std::stringstream ss;
-		clone->dump(ss);
-
-		EXPECT(original == ss.str());
-	}
-	if (filename.exists()) {
-		filename.unlink();
-	}
-}
-
 //-----------------------------------------------------------------------------
 
 }  // namespace test
